@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of INSPIRE-SCHEMAS.
-# Copyright (C) 2017 CERN.
+# Copyright (C) 2017, 2019 CERN.
 #
 # INSPIRE-SCHEMAS is free software; you can redistribute it
 # and/or modify it under the terms of the GNU General Public License as
@@ -25,7 +25,7 @@
 """Literature builder class and related code."""
 
 from __future__ import absolute_import, division, print_function
-from six import string_types
+from six import python_2_unicode_compatible, string_types, text_type
 
 import warnings
 
@@ -84,6 +84,7 @@ def key_already_there(element, elements):
     return False
 
 
+@python_2_unicode_compatible
 class LiteratureBuilder(object):
     """Literature record builder."""
 
@@ -125,11 +126,11 @@ class LiteratureBuilder(object):
 
     def __str__(self):
         """Print the current record."""
-        return str(self.record)
+        return text_type(self.record)
 
     def __repr__(self):
         """Printable representation of the builder."""
-        return 'LiteratureBuilder(source={!r}, record={})'.format(
+        return u'LiteratureBuilder(source={!r}, record={})'.format(
             self.source,
             self.record
         )
@@ -463,7 +464,7 @@ class LiteratureBuilder(object):
         if journal_title and all(
             not field for field in (cnum, artid, journal_issue,
                                     journal_volume, page_start, page_end)):
-            self.add_public_note('Submitted to {}'.format(journal_title))
+            self.add_public_note(u'Submitted to {}'.format(journal_title))
             return
 
         publication_item = {}
@@ -691,6 +692,21 @@ class LiteratureBuilder(object):
             'value': url
         })
 
+    @filter_empty_parameters
+    def add_external_system_identifier(self, extid, schema):
+        """Add external system identifier to ``external_system_identifiers``.
+
+        :param extid: external system identifier for the current document
+        :type extid: string
+
+        :param schema: identifies the external system for the given identifier
+        :type schema: string
+        """
+        self._append_to('external_system_identifiers', {
+            'schema': schema,
+            'value': extid,
+        })
+
     @filter_empty_parameters
     def add_report_number(self, report_number, source=None):
         """Add report numbers.
